==> haskell-skylighting-format-ansi-0.1-160-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-skylighting-format-ansi.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 skylighting-format-ansi
version:              0.1
visibility:           public
id:                   skylighting-format-ansi-0.1-2Ep9cKdBMOt7yMjo6Q3y6t
key:                  skylighting-format-ansi-0.1-2Ep9cKdBMOt7yMjo6Q3y6t
license:              BSD-3-Clause
copyright:            (C) 2016-2022 John MacFarlane
maintainer:           jgm@berkeley.edu
author:               John MacFarlane
homepage:             https://github.com/jgm/skylighting
synopsis:             ANSI formatter for skylighting syntax highlighting library
description:
    This module allows tokens produced by skylighting-core
    to be rendered as ANSI colored text.

category:             Text
abi:                  22ded3c8c8b738aaa952503b13979980
exposed:              True
exposed-modules:      Skylighting.Format.ANSI
import-dirs:          /usr/lib/ghc-9.2.8/site-local/skylighting-format-ansi-0.1
library-dirs:         /usr/lib/ghc-9.2.8/site-local/skylighting-format-ansi-0.1
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-skylighting-format-ansi
hs-libraries:         HSskylighting-format-ansi-0.1-2Ep9cKdBMOt7yMjo6Q3y6t
depends:
    ansi-terminal-1.0-4nG3Ezf0zRSL8RfVVMeUQ2 base-4.16.4.0
    binary-0.8.9.0 colour-2.3.6-AI2hzUqbPunFaDYRM0i4RP
    containers-0.6.5.1 skylighting-core-0.14.1.1-C3LArcQcgY6dBlENFyamG
    text-1.2.5.0

haddock-interfaces:
    /usr/share/doc/haskell-skylighting-format-ansi/html/skylighting-format-ansi.haddock

haddock-html:         /usr/share/doc/haskell-skylighting-format-ansi/html
' | '/usr/bin/ghc-pkg-9.2.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-skylighting-format-ansi-0.1-161-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-skylighting-format-ansi.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 skylighting-format-ansi
version:              0.1
visibility:           public
id:                   skylighting-format-ansi-0.1-J3SQTSHY5fG7s6HyOiv3Om
key:                  skylighting-format-ansi-0.1-J3SQTSHY5fG7s6HyOiv3Om
license:              BSD-3-Clause
copyright:            (C) 2016-2022 John MacFarlane
maintainer:           jgm@berkeley.edu
author:               John MacFarlane
homepage:             https://github.com/jgm/skylighting
synopsis:             ANSI formatter for skylighting syntax highlighting library
description:
    This module allows tokens produced by skylighting-core
    to be rendered as ANSI colored text.

category:             Text
abi:                  9937a6f0fd39f4d4939171bf184ad9fe
exposed:              True
exposed-modules:      Skylighting.Format.ANSI
import-dirs:          /usr/lib/ghc-9.2.8/site-local/skylighting-format-ansi-0.1
library-dirs:         /usr/lib/ghc-9.2.8/site-local/skylighting-format-ansi-0.1
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-skylighting-format-ansi
hs-libraries:         HSskylighting-format-ansi-0.1-J3SQTSHY5fG7s6HyOiv3Om
depends:
    ansi-terminal-1.0-B4Xn16XWLSCBu6tBrzW4At base-4.16.4.0
    binary-0.8.9.0 colour-2.3.6-6mRDx5VsJCs2S1QovYYv5V
    containers-0.6.5.1 skylighting-core-0.14.1.1-Bog9U2TTFCKgxwAuteuil
    text-1.2.5.0

haddock-interfaces:
    /usr/share/doc/haskell-skylighting-format-ansi/html/skylighting-format-ansi.haddock

haddock-html:         /usr/share/doc/haskell-skylighting-format-ansi/html
' | '/usr/bin/ghc-pkg-9.2.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
